@@ -1,25 +1,22 @@
-# Copyright 2012 OpenStack LLC.
-# All Rights Reserved.
+#   Copyright 2012-2013 OpenStack Foundation
 #
-#    Licensed under the Apache License, Version 2.0 (the "License"); you may
-#    not use this file except in compliance with the License. You may obtain
-#    a copy of the License at
+#   Licensed under the Apache License, Version 2.0 (the "License"); you may
+#   not use this file except in compliance with the License. You may obtain
+#   a copy of the License at
 #
-#         http://www.apache.org/licenses/LICENSE-2.0
+#        http://www.apache.org/licenses/LICENSE-2.0
 #
-#    Unless required by applicable law or agreed to in writing, software
-#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-#    License for the specific language governing permissions and limitations
-#    under the License.
+#   Unless required by applicable law or agreed to in writing, software
+#   distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#   License for the specific language governing permissions and limitations
+#   under the License.
 #
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
 
-"""
-Role action implementations
-"""
+"""Identity v2 Role action implementations"""
 
 import logging
+import six
 
 from cliff import command
 from cliff import lister
@@ -29,9 +26,8 @@ from openstackclient.common import utils
 
 
 class AddRole(show.ShowOne):
-    """Add role to tenant:user"""
+    """Add role to project:user"""
 
-    api = 'identity'
     log = logging.getLogger(__name__ + '.AddRole')
 
     def get_parser(self, prog_name):
@@ -39,46 +35,42 @@ class AddRole(show.ShowOne):
         parser.add_argument(
             'role',
             metavar='<role>',
-            help='Role name or ID to add to user',
-        )
+            help='Role name or ID to add to user')
         parser.add_argument(
-            '--tenant',
-            metavar='<tenant>',
+            '--project',
+            metavar='<project>',
             required=True,
-            help='Name or ID of tenant to include',
+            help='Include project (name or ID)',
         )
         parser.add_argument(
             '--user',
             metavar='<user>',
             required=True,
-            help='Name or ID of user to include',
-        )
+            help='Name or ID of user to include')
         return parser
 
     def take_action(self, parsed_args):
         self.log.debug('take_action(%s)' % parsed_args)
         identity_client = self.app.client_manager.identity
-        role = utils.find_resource(
-            identity_client.roles, parsed_args.role)
-        tenant = utils.find_resource(
-            identity_client.tenants, parsed_args.tenant)
-        user = utils.find_resource(
-            identity_client.users, parsed_args.user)
+        role = utils.find_resource(identity_client.roles, parsed_args.role)
+        project = utils.find_resource(
+            identity_client.tenants,
+            parsed_args.project,
+        )
+        user = utils.find_resource(identity_client.users, parsed_args.user)
         role = identity_client.roles.add_user_role(
             user,
             role,
-            tenant,
-        )
+            project)
 
         info = {}
         info.update(role._info)
-        return zip(*sorted(info.iteritems()))
+        return zip(*sorted(six.iteritems(info)))
 
 
 class CreateRole(show.ShowOne):
     """Create new role"""
 
-    api = 'identity'
     log = logging.getLogger(__name__ + '.CreateRole')
 
     def get_parser(self, prog_name):
@@ -86,26 +78,22 @@ class CreateRole(show.ShowOne):
         parser.add_argument(
             'role_name',
             metavar='<role-name>',
-            help='New role name',
-        )
+            help='New role name')
         return parser
 
     def take_action(self, parsed_args):
         self.log.debug('take_action(%s)' % parsed_args)
         identity_client = self.app.client_manager.identity
-        role = identity_client.roles.create(
-            parsed_args.role_name,
-        )
+        role = identity_client.roles.create(parsed_args.role_name)
 
         info = {}
         info.update(role._info)
-        return zip(*sorted(info.iteritems()))
+        return zip(*sorted(six.iteritems(info)))
 
 
 class DeleteRole(command.Command):
     """Delete existing role"""
 
-    api = 'identity'
     log = logging.getLogger(__name__ + '.DeleteRole')
 
     def get_parser(self, prog_name):
@@ -113,15 +101,13 @@ class DeleteRole(command.Command):
         parser.add_argument(
             'role',
             metavar='<role>',
-            help='Name or ID of role to delete',
-        )
+            help='Name or ID of role to delete')
         return parser
 
     def take_action(self, parsed_args):
         self.log.debug('take_action(%s)' % parsed_args)
         identity_client = self.app.client_manager.identity
-        role = utils.find_resource(
-            identity_client.roles, parsed_args.role)
+        role = utils.find_resource(identity_client.roles, parsed_args.role)
         identity_client.roles.delete(role.id)
         return
 
@@ -129,7 +115,6 @@ class DeleteRole(command.Command):
 class ListRole(lister.Lister):
     """List roles"""
 
-    api = 'identity'
     log = logging.getLogger(__name__ + '.ListRole')
 
     def take_action(self, parsed_args):
@@ -140,14 +125,12 @@ class ListRole(lister.Lister):
                 (utils.get_item_properties(
                     s, columns,
                     formatters={},
-                ) for s in data),
-               )
+                ) for s in data))
 
 
 class ListUserRole(lister.Lister):
     """List user-role assignments"""
 
-    api = 'identity'
     log = logging.getLogger(__name__ + '.ListUserRole')
 
     def get_parser(self, prog_name):
@@ -156,52 +139,56 @@ class ListUserRole(lister.Lister):
             'user',
             metavar='<user>',
             nargs='?',
-            help='Name or ID of user to include',
-        )
+            help='Name or ID of user to include')
         parser.add_argument(
-            '--tenant',
-            metavar='<tenant>',
-            help='Name or ID of tenant to include',
+            '--project',
+            metavar='<project>',
+            help='Include project (name or ID)',
         )
         return parser
 
     def take_action(self, parsed_args):
         self.log.debug('take_action(%s)' % parsed_args)
-        columns = ('ID', 'Name', 'Tenant ID', 'User ID')
         identity_client = self.app.client_manager.identity
 
         # user-only roles are not supported in KSL so we are
-        # required to have a user and tenant; default to the
+        # required to have a user and project; default to the
         # values used for authentication if not specified
-        if not parsed_args.tenant:
-            parsed_args.tenant = identity_client.auth_tenant_id
+        if not parsed_args.project:
+            parsed_args.project = identity_client.auth_tenant_id
         if not parsed_args.user:
             parsed_args.user = identity_client.auth_user_id
 
-        tenant = utils.find_resource(
-            identity_client.tenants, parsed_args.tenant)
-        user = utils.find_resource(
-            identity_client.users, parsed_args.user)
+        project = utils.find_resource(
+            identity_client.tenants,
+            parsed_args.project,
+        )
+        user = utils.find_resource(identity_client.users, parsed_args.user)
 
-        data = identity_client.roles.roles_for_user(user.id, tenant.id)
+        data = identity_client.roles.roles_for_user(user.id, project.id)
+
+        columns = (
+            'ID',
+            'Name',
+            'Project',
+            'User',
+        )
 
         # Add the names to the output even though they will be constant
         for role in data:
-            role.user_id = user.name
-            role.tenant_id = tenant.name
+            role.user = user.name
+            role.project = project.name
 
         return (columns,
                 (utils.get_item_properties(
                     s, columns,
                     formatters={},
-                ) for s in data),
-               )
+                ) for s in data))
 
 
 class RemoveRole(command.Command):
-    """Remove role from tenant:user"""
+    """Remove role from project:user"""
 
-    api = 'identity'
     log = logging.getLogger(__name__ + '.RemoveRole')
 
     def get_parser(self, prog_name):
@@ -209,42 +196,38 @@ class RemoveRole(command.Command):
         parser.add_argument(
             'role',
             metavar='<role>',
-            help='Role name or ID to remove from user',
-        )
+            help='Role name or ID to remove from user')
         parser.add_argument(
-            '--tenant',
-            metavar='<tenant>',
+            '--project',
+            metavar='<project>',
             required=True,
-            help='Name or ID of tenant',
+            help='Project to include (name or ID)',
         )
         parser.add_argument(
             '--user',
             metavar='<user>',
             required=True,
-            help='Name or ID of user',
-        )
+            help='Name or ID of user')
         return parser
 
     def take_action(self, parsed_args):
         self.log.debug('take_action(%s)' % parsed_args)
         identity_client = self.app.client_manager.identity
-        role = utils.find_resource(
-            identity_client.roles, parsed_args.role)
-        tenant = utils.find_resource(
-            identity_client.tenants, parsed_args.tenant)
-        user = utils.find_resource(
-            identity_client.users, parsed_args.user)
+        role = utils.find_resource(identity_client.roles, parsed_args.role)
+        project = utils.find_resource(
+            identity_client.tenants,
+            parsed_args.project,
+        )
+        user = utils.find_resource(identity_client.users, parsed_args.user)
         identity_client.roles.remove_user_role(
             user.id,
             role.id,
-            tenant.id,
-        )
+            project.id)
 
 
 class ShowRole(show.ShowOne):
     """Show single role"""
 
-    api = 'identity'
     log = logging.getLogger(__name__ + '.ShowRole')
 
     def get_parser(self, prog_name):
@@ -252,16 +235,14 @@ class ShowRole(show.ShowOne):
         parser.add_argument(
             'role',
             metavar='<role>',
-            help='Name or ID of role to display',
-        )
+            help='Name or ID of role to display')
         return parser
 
     def take_action(self, parsed_args):
         self.log.debug('take_action(%s)' % parsed_args)
         identity_client = self.app.client_manager.identity
-        role = utils.find_resource(
-            identity_client.roles, parsed_args.role)
+        role = utils.find_resource(identity_client.roles, parsed_args.role)
 
         info = {}
         info.update(role._info)
-        return zip(*sorted(info.iteritems()))
+        return zip(*sorted(six.iteritems(info)))
