@@ -1,25 +1,22 @@
-# Copyright 2012 OpenStack LLC.
-# All Rights Reserved.
+#   Copyright 2012-2013 OpenStack Foundation
 #
-#    Licensed under the Apache License, Version 2.0 (the "License"); you may
-#    not use this file except in compliance with the License. You may obtain
-#    a copy of the License at
+#   Licensed under the Apache License, Version 2.0 (the "License"); you may
+#   not use this file except in compliance with the License. You may obtain
+#   a copy of the License at
 #
-#         http://www.apache.org/licenses/LICENSE-2.0
+#        http://www.apache.org/licenses/LICENSE-2.0
 #
-#    Unless required by applicable law or agreed to in writing, software
-#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-#    License for the specific language governing permissions and limitations
-#    under the License.
+#   Unless required by applicable law or agreed to in writing, software
+#   distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+#   WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+#   License for the specific language governing permissions and limitations
+#   under the License.
 #
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
 
-"""
-Service action implementations
-"""
+"""Service action implementations"""
 
 import logging
+import six
 
 from cliff import command
 from cliff import lister
@@ -33,7 +30,6 @@ from openstackclient.common import utils
 class CreateService(show.ShowOne):
     """Create service command"""
 
-    api = 'identity'
     log = logging.getLogger(__name__ + '.CreateService')
 
     def get_parser(self, prog_name):
@@ -46,13 +42,11 @@ class CreateService(show.ShowOne):
             '--type',
             metavar='<service-type>',
             required=True,
-            help='New service type',
-        )
+            help='New service type')
         parser.add_argument(
             '--description',
             metavar='<service-description>',
-            help='New service description',
-        )
+            help='New service description')
         return parser
 
     def take_action(self, parsed_args):
@@ -61,18 +55,16 @@ class CreateService(show.ShowOne):
         service = identity_client.services.create(
             parsed_args.name,
             parsed_args.type,
-            parsed_args.description,
-        )
+            parsed_args.description)
 
         info = {}
         info.update(service._info)
-        return zip(*sorted(info.iteritems()))
+        return zip(*sorted(six.iteritems(info)))
 
 
 class DeleteService(command.Command):
     """Delete service command"""
 
-    api = 'identity'
     log = logging.getLogger(__name__ + '.DeleteService')
 
     def get_parser(self, prog_name):
@@ -80,8 +72,7 @@ class DeleteService(command.Command):
         parser.add_argument(
             'service',
             metavar='<service-id>',
-            help='ID of service to delete',
-        )
+            help='ID of service to delete')
         return parser
 
     def take_action(self, parsed_args):
@@ -94,7 +85,6 @@ class DeleteService(command.Command):
 class ListService(lister.Lister):
     """List service command"""
 
-    api = 'identity'
     log = logging.getLogger(__name__ + '.ListService')
 
     def get_parser(self, prog_name):
@@ -117,14 +107,12 @@ class ListService(lister.Lister):
                 (utils.get_item_properties(
                     s, columns,
                     formatters={},
-                ) for s in data),
-               )
+                ) for s in data))
 
 
 class ShowService(show.ShowOne):
-    """Show service command"""
+    """Show cloud service information"""
 
-    api = 'identity'
     log = logging.getLogger(__name__ + '.ShowService')
 
     def get_parser(self, prog_name):
@@ -132,28 +120,51 @@ class ShowService(show.ShowOne):
         parser.add_argument(
             'service',
             metavar='<service>',
-            help='Type, name or ID of service to display')
+            help='Type, name or ID of service to display',
+        )
+        parser.add_argument(
+            '--catalog',
+            action='store_true',
+            default=False,
+            help='Show service catalog information',
+        )
         return parser
 
     def take_action(self, parsed_args):
         self.log.debug('take_action(%s)' % parsed_args)
         identity_client = self.app.client_manager.identity
-        try:
-            # search for the usual ID or name
-            service = utils.find_resource(
-                identity_client.services, parsed_args.service)
-        except exceptions.CommandError:
-            try:
-                # search for service type
-                service = identity_client.services.find(
-                    type=parsed_args.service)
-            # FIXME(dtroyer): This exception should eventually come from
-            #                 common client exceptions
-            except identity_exc.NotFound:
-                msg = "No service with a type, name or ID of '%s' exists." % \
-                    name_or_id
-                raise exceptions.CommandError(msg)
 
-        info = {}
-        info.update(service._info)
-        return zip(*sorted(info.iteritems()))
+        if parsed_args.catalog:
+            endpoints = identity_client.service_catalog.get_endpoints(
+                service_type=parsed_args.service)
+            for (service, service_endpoints) in six.iteritems(endpoints):
+                if service_endpoints:
+                    info = {"type": service}
+                    info.update(service_endpoints[0])
+                    return zip(*sorted(six.iteritems(info)))
+
+            msg = ("No service catalog with a type, name or ID of '%s' "
+                   "exists." % (parsed_args.service))
+            raise exceptions.CommandError(msg)
+        else:
+            try:
+                # search for the usual ID or name
+                service = utils.find_resource(
+                    identity_client.services,
+                    parsed_args.service,
+                )
+            except exceptions.CommandError:
+                try:
+                    # search for service type
+                    service = identity_client.services.find(
+                        type=parsed_args.service)
+                # FIXME(dtroyer): This exception should eventually come from
+                #                 common client exceptions
+                except identity_exc.NotFound:
+                    msg = ("No service with a type, name or ID of '%s' exists."
+                           % parsed_args.service)
+                    raise exceptions.CommandError(msg)
+
+            info = {}
+            info.update(service._info)
+            return zip(*sorted(six.iteritems(info)))
